@@ -27,6 +27,14 @@ from pytorch_lightning.callbacks import RichProgressBar, TQDMProgressBar
 class BaseExperiment:
     r"""Parent class of ``Experiment``.
 
+    BaseExperiment basically trains the model with a certain random state governing all random operations. When test data is not specified, the test data would also be splitted 
+    differently depending on the randon state. To set a random state, you should specify the ``random_number`` argument as an input. This will set a random number generator with 
+    seed being the ``random_number``. Then, the created random number generator will generate a random state. 
+
+    All logs related to training will be logged in TensorBoard automatically. The directory for the Tensorboard depends on the type of training you do.
+    When you are performing cross validation, the log directory would be {path}/{project_name}/CV/random_state-{random_state}.
+    If you are doing regular fitting, the log directory would be {path}/{project_name}/FIT/random_state-{random_state}.
+
     Attributes:
 
         project_name (str): Name of the project. Directory of {path}/{project_name} will be created.
@@ -110,7 +118,7 @@ class BaseExperiment:
         stack_models : bool = True,
         random_number : int = 0,
         path : Optional[str] = None
-    ) -> None:
+    )->None:
         r"""
         Args:
 
@@ -369,7 +377,7 @@ class BaseExperiment:
                     test_size=self.test_size,
                     random_state=self.random_state
                 )
-                
+
             elif self.X_val is None and self.y_val is None and self.X_test is None and self.y_test is None:
                 data_module = initialize_datamodule(
                     batch_size=batch_size, 
@@ -482,9 +490,12 @@ class BaseExperiment:
         sample_weight : Optional["np.ndarray"] = None
     )->"BaseEstimator":
         # for consistency with the logging style of pytorch_lightning.
+        self.update_log_path()
         folder_dir = self.log_path + "/tensorboardlogs/" + self.model.__class__.__name__ 
-        version = len(os.listdir(folder_dir))
+        self._create_folder(folder_dir)
+        version = len(os.listdir(folder_dir)) - 1
         log_dir = folder_dir + "/" + self.model_metadata + "/" + "version_{}".format(version)
+        self._create_folder(log_dir)
         self.logger = SummaryWriter(log_dir=log_dir)
         self.model.fit(self.X_train, self.y_train, sample_weight)
         y_train_preds = self.model.predict(self.X_train)
@@ -545,7 +556,7 @@ class BaseExperiment:
         model : Optional[Union["pl.LightningModule", "BaseEstimator"]] = None,
         trainer : Optional["pl.Trainer"] = None,
         val_metrics : Optional[dict] = None
-    )-> None:
+    )->None:
         r"""Method for saving checkpoints. The logs are saved as json file as well.
         
         Args:
@@ -627,7 +638,7 @@ class BaseExperiment:
         self.log_metrics_to_json(model, tensorboard_logdir, version, val_metrics)
         self.update_exp_metadata()
     
-    def save_to_stack(self) -> None:
+    def save_to_stack(self)->None:
         r"""Method for stacking a model to ``stack``. If one of the ancestors of the model is ``BaseEstimator``, we only stack the model and its validation performance.
         If one of the ancestors of the model is ``LightningModule``, we stack a dictionary containing the model, its trainer, and its validation performance.
 
@@ -696,7 +707,7 @@ class BaseExperiment:
             raise NotImplementedError(f"Astrape only supports sklearn-based models and pl.LightningModule.")
    
     
-    def save_stack(self) -> None:
+    def save_stack(self)->None:
         r"""Method for saving all model checkpoints in ``stack``.
         
         Returns:
@@ -884,7 +895,7 @@ class BaseExperiment:
         hparams : dict,
         length_limit : int = 500,
         subtract : int = 30
-    ) -> str: 
+    )->str: 
         r"""Method for generating metadata of the experiment.
         
         Args:
@@ -955,7 +966,7 @@ class BaseExperiment:
         tensorboard_logdir: str,
         version : int,
         metrics_dict : Optional[dict] = None
-    ) -> None:
+    )->None:
         r"""Save results as a json file.
 
         Args:
@@ -1054,13 +1065,13 @@ class BaseExperiment:
         self.stack_models = not self.stack_models
 
     @staticmethod
-    def _create_folder(directory : str) -> str:
+    def _create_folder(directory : str)->str:
         r"""Creates folder. If folder already exists, does nothing."""
         os.makedirs(directory, exist_ok=True)
         return directory
 
     @staticmethod
-    def _dict_to_str(dictionary : dict) -> str:
+    def _dict_to_str(dictionary : dict)->str:
         r"""Polishes string form of the dictionary."""
         out = str(dictionary).replace("{", "").replace("}","").replace(" ","-").replace(":","").replace("-","").replace("\n", "-").replace('"', "").replace(".","d").replace("'","")
         return out
\ No newline at end of file
